@@ -27,9 +27,6 @@ def get_name():
     return "Date Time Clock"
 
 class DateTimeClock(clock.Clock):
-    def __init__(self, drawing_area):
-        clock.Clock.__init__(self, drawing_area)
-
     def draw_clock(self):
         self.context.set_font_size(int(self.text_scaling * 20))
 
