@@ -26,9 +26,6 @@ def get_name():
     return "Decimal Clock"
 
 class DecimalClock(clock.Clock):
-    def __init__(self, drawing_area):
-        clock.Clock.__init__(self, drawing_area)
-
     def draw_clock(self):
         self.context.set_font_size(int(self.text_scaling * 45))
         self.context.move_to(0, 35)
